#
# spec file for package pt2-clone
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pt2-clone
Version:        1.71
Release:        1.1
Summary:        ProTracker 2 clone
License:        BSD-3-Clause AND CC-BY-NC-SA-4.0
Group:          Productivity/Multimedia/Sound/Editors and Convertors
URL:            https://16-bits.org/pt2.php
#Git-Clone:     https://github.com/8bitbubsy/pt2-clone.git
Source:         https://github.com/8bitbubsy/%{name}/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(sdl2)

%description
Multi-platform clone of the classic music making software
ProTracker 2.3D.

%prep
%setup -q
# HACK: fix icon
sed 's|Icon=ProTracker 2 clone|Icon=pt2-clone|g' \
 -i "release/other/Freedesktop.org Resources/ProTracker 2 clone.desktop"

%build
%cmake
%cmake_build

%install
%cmake_install
install -Dpm 0644 "release/other/Freedesktop.org Resources/ProTracker 2 clone.desktop" %{buildroot}%{_datadir}/applications/%{name}.desktop
install -Dpm 0644 "release/other/Freedesktop.org Resources/ProTracker 2 clone.png" %{buildroot}%{_datadir}/pixmaps/%{name}.png

%files
%license LICENSE LICENSES.txt
%doc README.md release/{effects.txt,help.txt,keybindings.txt}
%doc release/other/protracker.ini
%{_bindir}/pt2-clone
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png

%changelog
* Tue Nov 26 2024 Martin Hauke <mardnh@gmx.de>
- Update to vaersion 1.71
  * MOD2WAV now exports to the current "modules" path, instead of
    the current open path (regardless of samples/modules mode) in
    Disk Op.
* Sun Sep  1 2024 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to version 1.70
  * You can now hold down the shift key while pressing the COPY
    button in the sample editor screen to clone the sample into the
    first free sample slot. If you have marked some portion of the
    sample data, then this slice will be copied instead of the
    whole sample.
  * Added a new config entry (RESTRICTED_PATT_EDIT_CLICK) for changing
    the behavior when clicking on the song pattern to change the
    current pattern to edit. This is to avoid annoying accidents.
    Check out the new protracker.ini for more information about
    this setting.
  * Windows/macOS: Updated SDL to v2.30.6
* Mon Apr 22 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.69
  * Hopefully fixed some stability issues with step-play
    (enter/backspace key)
  * Bugfix: Do not repeat step-play keys (enter/backspace)
- Update to version 1.68
  * Fixed some widget bugs when in "sample-zero" mode (sample = 00)
    This would happen if you did a click-and-hold on sample length,
    finetune, volume, loop, etc.
* Mon Mar 18 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.67
  * Fullscreen mode code has been refactored, as I apparently had
    coded it the wrong way. "Stretched" mode always fills the whole
    screen now too, and other issues may have been fixed as well.
  * The "INTEGERSCALING" option in protracker.ini has been removed
    as it wouldn't work with the new code anyway.
- Update to version 1.66
  * Fixed major sample trigger bugs with PAT2SMP.
* Mon Oct 30 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.65
  * Removed audio output dithering. It seemed to be wrongly
    implemented anyway.
  * Removed CTRL+G and CTRL+V keybinding (boost/filter all
    samples)
  * The BOOST (Edit Op. #3) function was not 100%% accurate to
    Amiga ProTracker.
* Thu Sep  7 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.64
  * Bugfix: A buffer overrun would occur if MOD2WAVFREQUENCY was
    set higher than FREQUENCY in protracker.ini while using
    MOD2WAV.
  * Right mouse button can now be held down while scrolling in
    Pos Ed. for faster scrolling speeds (forgot to implement this).
- Update to version 1.63
  * When loading raw samples, use the filename as the sample name.
* Tue Aug 29 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.62:
  * Bugfix: It was possible to scroll out of bounds in Disk Op. by
    using shift+key
  * Bugfix: Don't set "song unsaved" flag if text editing didn't
    make a change.
  * Bugfix: Editing the Disk Op. path text would set the
    "song unsaved" flag.
  * Bugfix: Using the "CLEAR" button while Edit. Op. or the about
    screen was open could lead to a screen redrawing issue.
  * Disk Op. file entry jumping (left shift + key) now works a bit
    differently. If the last pressed jump key didn't change, cycle
    through pages if there are more matches to be found. This
    allows for quicker module finding.
  * Re-implemented the Pos Ed. pattern naming feature. Be aware
    that this data is not saved to the module, and is only used to
    temporarily keep track of the patterns while making the module.
  * Code refactoring, a small portion of the code should be easier
    to understand now.
* Sat Jul 29 2023 Dirk Müller <dmueller@suse.com>
- update to 1.61:
  * De-minimize window (if minimized) and set focus after drag n'
    drop of file
* Mon Jun 19 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.60:
  * Added an AUTO mode for VIDEOSCALE in protracker.ini. This is
    now the default. It will use the most optimal window size
    based on the screen resolution. If you want this feature but
    don't want to replace protracker.ini, set VIDEOSCALE to AUTO
    (make sure you have v1.60 or later). Manual settings (2X, 3X,
    ...) still work like expected.
  * Removed VIDEOSCALE limit of 2X for ARM systems. This was
    originally meant for Raspberry Pi, but it would affect all
    ARM systems (except Apple).
* Sun Jun 11 2023 Dirk Müller <dmueller@suse.com>
- update to 1.59:
  * The "normalize" function in the sample editor's volume
    toolbox didn't work like it should if you had only selected
    one single sample point (for example after cutting sample
    data)
  * The (fake) spectrum analyzer is now more accurate to real PT
    in quirky cases
  * Some very small code changes not really worthy of a
    description
  * Updated effects.txt with the little known and undocumented
    effect "E8x"
- update to 1.58:
  * Added support for loading FLAC samples
  * The IFF sample saver was writing somewhat broken files for
    non-looped samples
  * The "UPSAMP" button in Edit Op. was showing the wrong status
    text
  * Small code refactor for how the song is timed/ticked. Longer
    song-to-WAV renders may have a filesize change of a few
    bytes, but this is actually more correct.
  * Increased number of precision bits for song BPM, playback
    time counter and audio->video syncing. This is a minor change
    and does very little in practice as the previous precision
    was already quite good.
  * Audio/video sync timestamps are reset every half an hour to
    prevent possible sync drifting after several hours of playing
    a song without a single song stop (resets timestamp) in-
    between
  * The HPC timers are reset every half an hour instead of every
    hour. The video (if no vsync) and the scopes use these
    timers. This hopefully fixes potential timing drifting issues
    that were still lingering.
  * Code refactoring for module/sample loaders
* Tue Feb 14 2023 Martin Hauke <mardnh@gmx.de>
- Initial package, version 1.57
